@@ -1209,10 +1209,10 @@ sub yt_browse_request {
                    context => {
                                client => {
                                           browserName      => "Firefox",
-                                          browserVersion   => "122.0",
+                                          browserVersion   => "136.0",
                                           clientFormFactor => "LARGE_FORM_FACTOR",
                                           clientName       => "MWEB",
-                                          clientVersion    => "2.20240201.00.00",
+                                          clientVersion    => "2.20250314.01.00",
                                           deviceMake       => "Mozilla",
                                           deviceModel      => "Firefox for Android",
                                           hl               => "en",
@@ -1221,15 +1221,15 @@ sub yt_browse_request {
                                                             },
                                           originalUrl        => $url,
                                           osName             => "Android",
-                                          osVersion          => "14",
-                                          platform           => "TABLET",
+                                          osVersion          => "16",
+                                          platform           => "MOBILE",
                                           playerType         => "UNIPLAYER",
                                           screenDensityFloat => 1,
                                           screenHeightPoints => 500,
                                           screenPixelDensity => 1,
                                           screenWidthPoints  => 1800,
                                           timeZone           => "UTC",
-                                          userAgent          => "Mozilla/5.0 (Android 14; Tablet; rv:109.0) Gecko/122.0 Firefox/122.0,gzip(gfe)",
+                                          userAgent          => "Mozilla/5.0 (Android 16 Beta 2; Mobile; rv:136.0) Gecko/136.0 Firefox/136.0,gzip(gfe)",
                                           userInterfaceTheme => "USER_INTERFACE_THEME_LIGHT",
                                           utcOffsetMinutes   => 0,
                                          },
@@ -1286,10 +1286,10 @@ sub yt_search_next_page {
                    "context" => {
                                  "client" => {
                                               "browserName"      => "Firefox",
-                                              "browserVersion"   => "122.0",
+                                              "browserVersion"   => "136.0",
                                               "clientFormFactor" => "LARGE_FORM_FACTOR",
                                               "clientName"       => "MWEB",
-                                              "clientVersion"    => "2.20240201.00.00",
+                                              "clientVersion"    => "2.20250314.01.00",
                                               "deviceMake"       => "Mozilla",
                                               "deviceModel"      => "Firefox for Android",
                                               "gl"               => "US",
@@ -1298,14 +1298,14 @@ sub yt_search_next_page {
                                                                    "graftUrl" => $url,
                                                                   },
                                               "osName"             => "Android",
-                                              "osVersion"          => "14",
-                                              "platform"           => "TABLET",
+                                              "osVersion"          => "16",
+                                              "platform"           => "MOBILE",
                                               "playerType"         => "UNIPLAYER",
                                               "screenDensityFloat" => 1,
                                               "screenHeightPoints" => 600,
                                               "screenPixelDensity" => 1,
                                               "screenWidthPoints"  => 1800,
-                                              "userAgent"          => "Mozilla/5.0 (Android 14; Tablet; rv:109.0) Gecko/122.0 Firefox/122.0,gzip(gfe)",
+                                              "userAgent"          => "Mozilla/5.0 (Android 16 Beta 2; Mobile; rv:136.0) Gecko/136.0 Firefox/136.0,gzip(gfe)",
                                               "userInterfaceTheme" => "USER_INTERFACE_THEME_LIGHT",
                                               "utcOffsetMinutes"   => 0,
                                              },
